ARObjectManager class

Manages the all node-related actions of an ARView

Constructors

ARObjectManager(int id, {bool debug = false})

Properties

debug → bool
Debugging status flag. If true, all platform calls are printed. Defaults to false.
final
hashCode → int
The hash code for this object.
no setterinherited
onNodeTap ↔ NodeTapResultHandler?
Callback function that is invoked when the platform detects a tap on a node
getter/setter pair
onPanChange ↔ NodePanChangeHandler?
getter/setter pair
onPanEnd ↔ NodePanEndHandler?
getter/setter pair
onPanStart ↔ NodePanChangeHandler?
getter/setter pair
onRotationChange ↔ NodePanChangeHandler?
getter/setter pair
onRotationEnd ↔ NodePanEndHandler?
getter/setter pair
onRotationStart ↔ NodePanChangeHandler?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addNode(ARNode node, {ARPlaneAnchor? planeAnchor}) → Future<bool?>
Add given node to the given anchor of the underlying AR scene (or to its top-level if no anchor is given) and listen to any changes made to its transformation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onInitialize() → dynamic
Sets up the AR Object Manager
removeNode(ARNode node) → dynamic
Remove given node from the AR Scene
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited