ARAnchor class abstract

Object attached to a tracked physical entity of the AR environment (can be initialized with a world transformation)

Implementers

Constructors

ARAnchor({required AnchorType type, required Matrix4 transformation, String? name})
ARAnchor.fromJson(Map<String, dynamic> arguments)
Constructs an ARAnchor from a serialized anchor object
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Determines the name of the ARAnchor Will be autogenerated if not defined.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformation → Matrix4
Defines the anchor’s rotation, translation and scale in world coordinates.
final
type → AnchorType
Specifies the AnchorType of this ARAnchor
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes an ARAnchor
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited