ARHitTestResult class

A result (type, distance from the camera, world transformation) of an intersection found during a hit-test.

Constructors

ARHitTestResult(ARHitTestResultType type, double distance, Matrix4 worldTransform)

Properties

distance → double
The distance from the camera to the intersection in meters.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ARHitTestResultType
The type of the hit-test result.
final
worldTransform → Matrix4
The transformation matrix that defines the intersection’s rotation, translation and scale relative to the world.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes the ARHitTestResult
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ARHitTestResult
Instantiates am ARHitTestResult from a serialized ARHitTestResult