models/ar_node library

Classes

ARNode
ARNode is the model class for node-tree objects. It encapsulates the position, rotations, and other transforms of a node, which define a coordinate system. The coordinate systems of all the sub-nodes are relative to the one of their parent node.
MatrixValueNotifierConverter

Extensions

Matrix4Extenstion on Matrix4

Functions

createTransformMatrix(Matrix4? origin, Vector3? position, Vector3? scale, Vector4? rotation, Vector3? eulerAngles) → Matrix4
Helper function to create a Matrix4 from either a given matrix or from position, scale and rotation relative to the origin